@@ -88,7 +88,7 @@ class TransformingAutoEncoderController(HybridBlock, ControllableModel):
             initializer:                    is-a `mxnet.initializer` for parameters of model. If `None`, it is drawing from the Xavier distribution.
 
         '''
-        super(TransformingAutoEncoderController, self).__init__(**kwargs)
+        super(TransformingAutoEncoderController, self).__init__()
 
         if computable_loss is None:
             computable_loss = gluon.loss.SoftmaxCrossEntropyLoss(
