@@ -133,7 +133,7 @@ class ConvolutionalNeuralNetworks(HybridBlock, ObservableData):
         if isinstance(computable_loss, ComputableLoss) is False and isinstance(computable_loss, gluon.loss.Loss) is False:
             raise TypeError("The type of `computable_loss` must be `ComputableLoss` or `gluon.loss.Loss`.")
 
-        super(ConvolutionalNeuralNetworks, self).__init__(**kwargs)
+        super(ConvolutionalNeuralNetworks, self).__init__()
 
         with self.name_scope():
             if input_nn is not None:
